@@ -38,10 +38,9 @@ using namespace KontactInterface;
 #include <tlhelp32.h>
 #include <psapi.h>
 #include <signal.h>
-#include <unistd.h>
 
-#include <QtCore/QList>
-#include <QtCore/QtDebug>
+#include <QList>
+#include <QtDebug>
 
 #include <QCoreApplication>
 #include "kontactinterface_debug.h"
@@ -95,7 +94,7 @@ static HANDLE getProcessHandle(int processID)
                        false, processID);
 }
 
-void KPIMUtils::getProcessesIdForName(const QString &processName, QList<int> &pids)
+void KontactInterface::getProcessesIdForName(const QString &processName, QList<int> &pids)
 {
     HANDLE h;
     PROCESSENTRY32 pe32;
@@ -136,7 +135,7 @@ void KPIMUtils::getProcessesIdForName(const QString &processName, QList<int> &pi
     CloseHandle(h);
 }
 
-bool KPIMUtils::otherProcessesExist(const QString &processName)
+bool KontactInterface::otherProcessesExist(const QString &processName)
 {
     QList<int> pids;
     getProcessesIdForName(processName, pids);
@@ -150,7 +149,7 @@ bool KPIMUtils::otherProcessesExist(const QString &processName)
     return false;
 }
 
-bool KPIMUtils::killProcesses(const QString &processName)
+bool KontactInterface::killProcesses(const QString &processName)
 {
     QList<int> pids;
     getProcessesIdForName(processName, pids);
@@ -160,6 +159,8 @@ bool KPIMUtils::killProcesses(const QString &processName)
 
     qCWarning(KONTACTINTERFACE_LOG) << "Killing process \"" << processName << " (pid=" << pids[0] << ")..";
     int overallResult = 0;
+    qDebug() << "NEED TO PORT KILL PROCESS ON WINDOWS";
+#if 0
     foreach (int pid, pids) {
         int result;
         result = kill(pid, SIGTERM);
@@ -171,6 +172,7 @@ bool KPIMUtils::killProcesses(const QString &processName)
             overallResult = result;
         }
     }
+#endif
     return overallResult == 0;
 }
 
@@ -195,10 +197,10 @@ BOOL CALLBACK EnumWindowsProc(HWND hwnd, LPARAM lParam)
     return TRUE;
 }
 
-void KPIMUtils::activateWindowForProcess(const QString &executableName)
+void KontactInterface::activateWindowForProcess(const QString &executableName)
 {
     QList<int> pids;
-    KPIMUtils::getProcessesIdForName(executableName, pids);
+    KontactInterface::getProcessesIdForName(executableName, pids);
     int myPid = QCoreApplication::applicationPid();
     int foundPid = 0;
     foreach (int pid, pids) {
